@@ -553,6 +553,15 @@ impl VisitMut for ReduceAst {
     ///
     ///  - empty [Expr::Seq] => [Expr::Invalid]
     fn visit_mut_expr(&mut self, e: &mut Expr) {
+        match e {
+            Expr::Bin(BinExpr { left, right, .. }) => {
+                if is_related_to_process(&left) || is_related_to_process(&right) {
+                    return;
+                }
+            }
+            _ => {}
+        }
+
         match e {
             Expr::Call(CallExpr {
                 callee: ExprOrSuper::Expr(callee),
@@ -1814,6 +1823,17 @@ impl VisitMut for ReduceAst {
     }
 }
 
+fn is_related_to_process(right: &Expr) -> bool {
+    match right {
+        Expr::Ident(i) => &*i.sym == "process",
+        Expr::Member(MemberExpr {
+            obj: ExprOrSuper::Expr(obj),
+            ..
+        }) => is_related_to_process(&obj),
+        _ => false,
+    }
+}
+
 fn preserve_pat_or_expr(exprs: &mut Vec<Box<Expr>>, p: PatOrExpr) {
     match p {
         PatOrExpr::Expr(e) => {
